from django.db.models import signals

def create_site(app, created_models, verbosity, db, **kwargs):
    from django.contrib.sites.models import Site
    from cyclope.models import Menu, MenuItem, Layout, SiteSettings
    models = (Menu, MenuItem, Layout, SiteSettings)
    if all([model in created_models for model in models]) and \
        not Menu.objects.all():
        # Domain name
        domain = "localhost:8000"
        if kwargs.get('interactive', True):
            msg = "\nDomain name (leave empty for default: %s: " % domain
            input_domain = raw_input(msg)
            domain = input_domain or domain
        # Site name
        site_name = "Cyclope demo"
        if kwargs.get('interactive', True):
            msg = "\nSite name (leave empty for default: %s): " % site_name
            input_name = raw_input(msg)
            site_name = input_name or site_name
        if Site.objects.all():
            site = Site.objects.all()[0]
        else:
            site = Site()
        site.domain = domain
        site.name = site_name
        site.save(using=db)

        menu = Menu(name="Main menu", main_menu=True)
        menu.save(using=db)

        layout = Layout(name="default", template='five_elements.html')
        layout.save(using=db)

        menu_item = MenuItem(menu=menu, name="home", site_home=True,
                             active=True, layout=layout)

        menu_item.save(using=db)

        site_settings = SiteSettings(site=site, theme="neutronix",
                                     default_layout=layout, allow_comments='YES')
        site_settings.save(using=db)

def create_contact_form_settings(app, created_models, verbosity, db, **kwargs):
    from contact_form.models import ContactFormSettings

    if ContactFormSettings in created_models and not ContactFormSettings.objects.all():
        cfs = ContactFormSettings(subject="Contact mail")
        cfs.save(using=db)

def create_user_groups(app, created_models, verbosity, db, **kwargs):
    from django.contrib.auth.models import User, Group
    if User in created_models and Group in created_models:
        for g in ("editors", "managers", "translators"):
            group, created = Group.objects.get_or_create(name=g)
            if created:
                group.save(using=db)


signals.post_syncdb.connect(create_site)

signals.post_syncdb.connect(create_contact_form_settings)

signals.post_syncdb.connect(create_user_groups, dispatch_uid="create_cyclope_user_groups")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.sitemaps import Sitemap

from cyclope.models import MenuItem
from cyclope.core.collections.models import Collection, Category
import cyclope.settings as cyc_settings


class CategorySitemap(Sitemap):
    changefreq = "weekly"
    priority = 0.2

    def items(self):
        return Category.objects.filter(collection__visible = True)


class CollectionSitemap(Sitemap):
    changefreq = "weekly"
    priority = 0.3

    def items(self):
        return Collection.objects.filter(visible=True)


class MenuSitemap(Sitemap):
    changefreq = "monthly"
    priority = 0.7

    def items(self):

        menu_items = MenuItem.objects.filter(active=True).exclude(
                                                    custom_url__contains="http")
        return menu_items

    def location(self, obj):
        return obj.custom_url or cyc_settings.CYCLOPE_PREFIX + "/" + obj.url



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):

        # Adding model 'UserProfile'
        db.create_table('cyclope_userprofile', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], unique=True)),
            ('avatar', self.gf('django.db.models.fields.files.ImageField')(max_length=100, blank=True)),
            ('city', self.gf('django.db.models.fields.CharField')(max_length=100, blank=True)),
            ('about', self.gf('django.db.models.fields.TextField')(max_length=1000, blank=True)),
            ('public', self.gf('django.db.models.fields.BooleanField')(default=True, blank=True)),
        ))
        db.send_create_signal('cyclope', ['UserProfile'])


    def backwards(self, orm):

        # Deleting model 'UserProfile'
        db.delete_table('cyclope_userprofile')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'cyclope.author': {
            'Meta': {'object_name': 'Author'},
            'content_types': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['contenttypes.ContentType']", 'db_index': 'True', 'symmetrical': 'False'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'default': "''", 'max_length': '100', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'notes': ('django.db.models.fields.TextField', [], {'default': "''", 'blank': 'True'}),
            'origin': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '250', 'db_index': 'True', 'blank': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'})
        },
        'cyclope.image': {
            'Meta': {'object_name': 'Image'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100'})
        },
        'cyclope.layout': {
            'Meta': {'object_name': 'Layout'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50', 'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'template': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'cyclope.menu': {
            'Meta': {'object_name': 'Menu'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'main_menu': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50', 'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'})
        },
        'cyclope.menuitem': {
            'Meta': {'object_name': 'MenuItem'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True', 'blank': 'True'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'menu_entries'", 'null': 'True', 'to': "orm['contenttypes.ContentType']"}),
            'content_view': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'blank': 'True'}),
            'custom_url': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '200', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'layout': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cyclope.Layout']", 'null': 'True', 'blank': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'menu': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'menu_items'", 'to': "orm['cyclope.Menu']"}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "u'children'", 'null': 'True', 'to': "orm['cyclope.MenuItem']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'site_home': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'url': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255', 'db_index': 'True'})
        },
        'cyclope.regionview': {
            'Meta': {'object_name': 'RegionView'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'region_views'", 'null': 'True', 'to': "orm['contenttypes.ContentType']"}),
            'content_view': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'layout': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cyclope.Layout']"}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'region': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '100', 'blank': 'True'}),
            'weight': ('django.db.models.fields.PositiveIntegerField', [], {'default': '0', 'null': 'True', 'blank': 'True'})
        },
        'cyclope.sitesettings': {
            'Meta': {'object_name': 'SiteSettings'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'max_length': '4'}),
            'default_layout': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cyclope.Layout']", 'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'default': "''", 'blank': 'True'}),
            'global_title': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '250', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'keywords': ('django.db.models.fields.TextField', [], {'default': "''", 'blank': 'True'}),
            'site': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['sites.Site']", 'unique': 'True'}),
            'theme': ('django.db.models.fields.CharField', [], {'max_length': '250'})
        },
        'cyclope.source': {
            'Meta': {'object_name': 'Source'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'link': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '250', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '250', 'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'})
        },
        'cyclope.userprofile': {
            'Meta': {'object_name': 'UserProfile'},
            'about': ('django.db.models.fields.TextField', [], {'max_length': '1000', 'blank': 'True'}),
            'avatar': ('django.db.models.fields.files.ImageField', [], {'max_length': '100', 'blank': 'True'}),
            'city': ('django.db.models.fields.CharField', [], {'max_length': '100', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'public': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'unique': 'True'})
        },
        'sites.site': {
            'Meta': {'object_name': 'Site', 'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        }
    }

    complete_apps = ['cyclope']



from django.db import models, IntegrityError
from django.template.loader import render_to_string
from django.core.mail import mail_managers
from django.contrib.sites.models import Site
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.models import User
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes import generic


from . import registry

class AbuseType(models.Model):

    name = models.CharField(_('name'), max_length=100)

    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name = _('abuse types')
        verbose_name_plural = _('abuses types')

class AbuseReportElement(models.Model):
    content_type = models.ForeignKey(ContentType, verbose_name=_('content type'))
    object_id = models.PositiveIntegerField(_('object'))
    content_object = generic.GenericForeignKey('content_type', 'object_id')
    abuse_type = models.ForeignKey(AbuseType, verbose_name=_('abuse type'))
    user = models.ForeignKey(User)
    date = models.DateTimeField(auto_now_add=True)
    text = models.TextField(blank=True)
    report = models.ForeignKey('AbuseReport')

    def __unicode__(self):
        return unicode(self.content_object)

    def save(self, *args, **kwargs):
        if not self.content_type.model_class() in registry:
            raise Exception("Cannot report abuse for %s" % self.content_type)
        report, created = AbuseReport.objects.get_or_create(content_type=self.content_type,
                                                            object_id=self.object_id)
        self.report = report
        super(AbuseReportElement, self).save(*args, **kwargs)

        if self.report.status in ("REP", "HOLD"):
            # send mail to managers
            subject = _("Abuse report for object %s") % self.content_object
            message = render_to_string("abuse/abuse_report_email.txt",
                                      {"element": self,
                                       "domain": Site.objects.get_current().domain})
            mail_managers(subject, message, fail_silently=True)

    class Meta:
        verbose_name = _('abuse report elements')
        verbose_name_plural = _('abuses reports elements')
        unique_together = ("user", "content_type", "object_id")

class AbuseReport(models.Model):
    content_type = models.ForeignKey(ContentType, verbose_name=_('content type'))
    object_id = models.PositiveIntegerField(_('object'))
    content_object = generic.GenericForeignKey('content_type', 'object_id')
    status = models.CharField(_('status'), max_length=4,
                                choices = (
                                    ('REP',_('reported')),
                                    ('HOLD',_('on hold')),
                                    ('IGN',_('ignored')),
                                    ('DEL',_('deleted'))
                                ), default='REP')

    def _get_elements(self):
        return AbuseReportElement.objects.filter(content_type=self.content_type,
                                                  object_id=self.object_id)

    def count(self):
        return len(self._get_elements())

    def date(self):
        elem = self._get_elements().order_by('date')[0:1].get()
        return elem.date

    def user(self):
        elem = self._get_elements().order_by('date')[0:1].get()
        return elem.user

    def object(self):
        return self.content_object

    def link(self):
        obj = self.content_object
        return u'<a href="%s">%s</a>' % (obj.get_absolute_url(), obj)

    def __unicode__(self):
        return _("Report: %d") % self.id

    def save(self, *args, **kwargs):
        if AbuseReport.objects.filter(pk=self.pk).exists():
            if self.status == "DEL":
                if self.content_object:
                    if hasattr(self.content_object, 'user'):
                        user = self.content_object.user
                        # TODO
                        user.email_user(subject, message)
                    self.content_object.delete()
                    self.abusereportelement_set.all().delete()
                    self.delete()
                    return

        super(AbuseReport, self).save(*args, **kwargs)

    link.allow_tags = True

    class Meta:
        verbose_name = _('abuse report')
        verbose_name_plural = _('abuses reports')




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
widgets
-------
"""

import re

from django import forms
from django.conf import settings
from django.forms.util import flatatt
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext_lazy as _
from django.utils.html import escape
from django.utils.text import truncate_words
from django.utils.html import conditional_escape
from django.utils.encoding import force_unicode
from django.core.urlresolvers import reverse
from django.contrib.admin.widgets import ForeignKeyRawIdWidget, AdminTextareaWidget

from markitup.widgets import AdminMarkItUpWidget, MarkItUpWidget

from cyclope import settings as cyc_settings


def get_default_text_widget():
    if cyc_settings.CYCLOPE_TEXT_STYLE == 'textile':
        widget = FBAdminMarkItUpWidget
    elif cyc_settings.CYCLOPE_TEXT_STYLE == 'wysiwyg':
        widget = CKEditor
    else:
        widget = AdminTextareaWidget
    return widget


class CKEditor(forms.Textarea):
    """
    Widget providing CKEditor for Rich Text Editing.
    """
    class Media:
        js = (
            cyc_settings.CYCLOPE_STATIC_URL + 'ckeditor/ckeditor.js',
        )

    def render(self, name, value, attrs={}):
        language = settings.LANGUAGE_CODE[:2]
        if value is None: value = ''
        final_attrs = self.build_attrs(attrs, name=name)
        return mark_safe(u'''<textarea%s>%s</textarea>
        <script type="text/javascript">

            CKEDITOR.replace("%s",
                {
                    toolbar : // http://docs.cksource.com/CKEditor_3.x/Developers_Guide/Toolbar
                        [
                            ['Cut','Copy','Paste','PasteText'],
                            ['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
                            ['BidiLtr', 'BidiRtl'],
                            '/',
                            ['Bold','Italic','Underline','Strike','-','Subscript','Superscript'],
                            ['NumberedList','BulletedList','-','Outdent','Indent','Blockquote'],
                            ['JustifyLeft','JustifyCenter','JustifyRight','JustifyBlock'],
                            ['Link','Unlink'],
                            ['Image','Flash','Table','HorizontalRule'],
                            '/',
                            ['Styles','Format','Font','FontSize'],
                            ['TextColor','BGColor']
                        ],
                    skin: "v2",
                    height:"291",
                    width:"618",
                    filebrowserUploadUrl : "%s",
                    filebrowserBrowseUrl : "%s",
                    language : "%s",
                }
            );
            // Customizing dialogs
            CKEDITOR.on( 'dialogDefinition', function( ev ){
                    var dialogName = ev.data.name;
                    var dialogDefinition = ev.data.definition;
                    if ( dialogName == 'link' )
                    {
                        dialogDefinition.removeContents( 'advanced' );
                        dialogDefinition.removeContents( 'upload' );
                    }

                    if ( dialogName == 'image' )
                    {
                        dialogDefinition.removeContents( 'advanced' );
                        dialogDefinition.removeContents( 'Upload' );
                    }

                    if ( dialogName == 'flash' )
                    {
                        dialogDefinition.removeContents( 'advanced' );
                        dialogDefinition.removeContents( 'Upload' );
                    }

            });
        </script>''' % (flatatt(final_attrs),
                        conditional_escape(force_unicode(value)),
                        final_attrs['id'],
                        "/", # FIXME http://docs.cksource.com/CKEditor_3.x/Developers_Guide/File_Browser_%28Uploader%29
                        reverse('fb_browse')+'?pop=3', # pop=3 is CKEditor
                        language))


class MultipleWidget(forms.Widget):
    """
    Widget formed by multiple fields. Use with MultipleField.
    """
    def __init__(self, fields, *args, **kwargs):
        self.fields = fields
        super(MultipleWidget, self).__init__(*args, **kwargs)
        self._field_regexp = re.compile("multiple_(.*)")

    def render(self, name, value, *args, **kwargs):
        if value is None or value is u"":
            value = {}
        out_names = ['%s_multiple_%s' % (name, field_name) for field_name in self.fields.keys()]
        out = []
        out.append("<fieldset class='module'>")
        #out.append('<a class="collapse-toggle" href="#"> Show </a>')
        field_names, fields = self.fields.iterkeys(), self.fields.itervalues()
        for field_name, field, out_name in zip(field_names, fields, out_names):
            out.append("<div class='form-row'>")
            out.append(unicode(field.label)+u": " )
            out.append(field.widget.render(out_name, value.get(field_name)))
            out.append("</div>")
        out.append("</fieldset>")
        return mark_safe(u"<div id='%s_multiple'>" % name + u'\n'.join(out) +u"</div>")

    def value_from_datadict(self, data, files, name):
        out_names = ['%s_multiple_%s' % (name, field_name) for field_name in self.fields.keys()]
        values = {}
        for out_name in out_names:
            field_name = self._field_regexp.search(out_name).groups()[0]
            values[field_name] = data.get(out_name)
        return values


class FBAdminMarkItUpWidget(AdminMarkItUpWidget):
    def render(self, name, value, attrs=None):
        html = super(MarkItUpWidget, self).render(name, value, attrs)

        if self.auto_preview:
            auto_preview = "$('a[title=\"Preview\"]').trigger('mouseup');"
        else: auto_preview = ''

        html += ('<script type="text/javascript">'
                '(function($) { '
                 '$(document).ready(function() {'
                 '  $("#%(id)s").markItUp(mySettings);'
                 '  %(auto_preview)s '
                 'FileBrowserHelper.insertPicture("%(id)s");'
                 '});'
                 '})(jQuery);'

                 '</script>' % {'id': attrs['id'],
                                'auto_preview': auto_preview })
        return mark_safe(html)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
Based on patches #9976 (https://code.djangoproject.com/ticket/9976)

"""

import re

from django import forms
from django.conf import settings
from django.utils.safestring import mark_safe
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.models import ContentType
from django.contrib.admin.widgets import ForeignKeyRawIdWidget

from views import do_render_object
from fields import GenericModelChoiceField


generic_script = """
<script type="text/javascript">
function showGenericRelatedObjectLookupPopup(ct_field, triggering_link, url_base) {
    console.log(ct_field);
    console.log(triggering_link);
    var id_name = triggering_link.id.replace(/^lookup_/, '');
    // If ct is inline
    var indx_prefix = ct_field.indexOf("__prefix__")
    if (indx_prefix != -1){
        // get the index of the inline
        var index = triggering_link.id.split("lookup_id_")[1].slice(indx_prefix).split("-")[0];
        ct_field = ct_field.replace("__prefix__", index);
    }
    ct_select = document.getElementById('id_' + ct_field);
    var getCTId = function(ct_select){
        return ct_select.options[ct_select.selectedIndex].value;
    }
    var ct_id = getCTId(ct_select);
    var url = content_types[ct_id];

    function setNewValue(id_name, value){
        var obj = $("#"+id_name);
        obj.attr("newValue", value);
        obj.val(value);
    }

    var ensureRepresentation = function(id_name, ct_select){
        var obj = $("#"+id_name);
        var ct_id = getCTId(ct_select);
        if (obj.attr("value") !== obj.attr("newValue")){
            console.log(ct_id);
            var obj_id = obj.attr("value");
            setNewValue(id_name, ct_id + "-" + obj.attr("value"));
            $.get("/related_admin/render_object/"+ct_id+"/"+obj_id+"/", function(data) {
                obj.siblings(".object-representation").html(data);
            });
        }
    }
    // Yes this is insane but there isn't a robust way to fire an event by a
    // closing window that has a long ajax function inside without blocking
    setInterval(function() {ensureRepresentation(id_name, ct_select); }, 200);

    if (url != undefined) {
        triggering_link.href = url_base + url;
        var rv = showRelatedObjectLookupPopup(triggering_link);
        setNewValue(id_name, "");
        return rv;
    }
    return false;
}

$(".vGenericFKAdminField").css("display", "none");

</script>
"""

class GenericFKWidget(ForeignKeyRawIdWidget):
    def __init__(self, ct_field, cts=None, attrs=None):
        self.ct_field = ct_field
        if cts is None:
            cts = []
        self.cts = cts
        forms.TextInput.__init__(self, attrs)
        self.content_types = """
        <script type="text/javascript">
        var content_types = new Array();
        %s
        </script>
        """ % ('\n'.join(["content_types[%s] = '%s/%s/';" % (ContentType.objects.get_for_model(ct).id,
                                                             ct._meta.app_label, ct._meta.object_name.lower())
                                                             for ct in self.cts]))

    def render(self, name, value, attrs=None):
        # if it is inline build the proper ct_field name
        ct_field = self.ct_field
        if "__prefix__" in name:
            ct_field = re.sub('__prefix__.*', "__prefix__-" + ct_field, name)
        elif re.match('.*\-(\d+\-).*', name):
            ct_field = re.sub('(\d+\-).*', "\g<1>" + ct_field , name)
        self._test_ct_field = ct_field # for testing purposes only
        try:
            actual_object = GenericModelChoiceField.to_python(value)
        except forms.ValidationError:
            actual_object = None
        if attrs is None:
            attrs = {}
        related_url = '../../../'
        params = self.url_parameters()
        if params:
            url = '?' + '&amp;'.join(['%s=%s' % (k, v) for k, v in params.iteritems()])
        else:
            url = ''
        if 'class' not in attrs:
            attrs['class'] = 'vGenericFKAdminField'
        output = [forms.TextInput.render(self, name, value, attrs)]
        output.append('<div class="object-representation float-left">%s</div>' % (do_render_object(actual_object) if actual_object else ""))
        output.append("""%(generic_script)s
            <a href="%(related)s%(url)s" class="related-lookup" id="lookup_id_%(name)s" onclick="return showGenericRelatedObjectLookupPopup('%(ct_field)s', this, '%(related)s%(url)s');"> """
             % {'generic_script': generic_script, 'related': related_url, 'url': url, 'name': name, 'ct_field': ct_field})
        output.append('<img src="%simg/selector-search.gif" width="16" height="16" alt="%s" /></a>' % (settings.STATIC_URL + "admin/", 'Lookup'))
        return mark_safe(u''.join(output) + self.content_types)

    def url_parameters(self):
        return {}



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur Asoc. Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
core.perms.models
-------------------
"""

from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _

from cyclope.core.collections.models import Category


class CategoryPermission(models.Model):
    user = models.ForeignKey(User, verbose_name=_('user'))
    can_edit_content = models.BooleanField(_('can edit content'))
    can_add_content = models.BooleanField(_('can add content'))
    category = models.ForeignKey(Category, verbose_name=_('category'))

    class Meta:
        unique_together = ('category', 'user')
        verbose_name = _('category permission')
        verbose_name_plural = _('category permissions')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
GenericModelChoiceField based on django-autocomplete-light
from James Pic and contributors.
https://github.com/yourlabs/django-autocomplete-light
"""


from django import forms
from django.db import models
from django.forms import fields
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.models import ContentType

class GenericModelChoiceField(fields.Field):
    """
    Simple form field that converts strings to models.
    """
    def validate(self, value):
        super(GenericModelChoiceField, self).validate(value)
        if not value and not self.required:
            return True

        value = self.prepare_value(value)
        try:
            self.to_python(value)
        except:
            raise forms.ValidationError(_(u'field %(field)s cannot validate %(value)s') %
                                        {"field":self, "value":value})

    def prepare_value(self, value):
        """
        Given a model instance as value, with content type id of 3 and pk of 5,
        return such a string '3-5'.
        """
        if isinstance(value, (str, unicode)):
            # Apparently there's a bug in django, that causes a python value to
            # be passed here. This ONLY happens when in an inline ....
            return value
        elif isinstance(value, models.Model):
            return '%s-%s' % (ContentType.objects.get_for_model(value).pk,
                              value.pk)

    @classmethod
    def to_python(self, value):
        """
        Given a string like '3-5', return the model of content type id 3 and pk
        5.
        """
        if not value:
            return None
        try:
            content_type_id, object_id = value.split('-')
            content_type = ContentType.objects.get_for_id(content_type_id)
        except (ContentType.DoesNotExist, ValueError):
            raise forms.ValidationError(_(u'Wrong content type or object'))
        else:
            model = content_type.model_class()

        return model.objects.get(pk=object_id)



import logging
from string import strip

try:
    from premailer import Premailer
except:
    pass

from django.http import HttpResponse, HttpResponseRedirect
from django.template import RequestContext
from django.contrib.auth.decorators import permission_required
from django.template import loader
from django.core.mail import EmailMessage
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from cyclope.core import frontend
from cyclope import settings as cyc_settings
from cyclope.core.collections.models import Category
from models import Newsletter


def _newsletter_html(request, newsletter):
    category = newsletter.content_category
    template_name = cyc_settings.CYCLOPE_THEME_PREFIX + newsletter.layout.template
    nl_template = loader.get_template(template_name)
    categorizations_list = category.categorizations.all()
    categorizations_list = sorted(categorizations_list,
                                  key=lambda c: c.object_modification_date,
                                  reverse=True)

    context = RequestContext(request, {'host_template': nl_template,
                                       'layout': newsletter.layout,
                                       'newsletter': newsletter,
                                       'categorizations': categorizations_list,
                                       })
    content_view = frontend.site.get_view(Newsletter, newsletter.view)

    html = content_view.get_response(request, context, options={},
                                     content_object=newsletter)
    return html


@permission_required('newsletter.change_newsletter')
def preview(request, id):
    newsletter = Newsletter.objects.get(id=id)

    # some of these are the default parameters but we include them in case some tunning is needed later on. Premailer documentation is scarce
    pm = Premailer(_newsletter_html(request, newsletter),
                   base_url=cyc_settings.CYCLOPE_BASE_URL,
                   preserve_internal_links=True,
                   exclude_pseudoclasses=False,
                   keep_style_tags=False, include_star_selectors=False,
                   external_styles=None)
    result = pm.transform()
    return HttpResponse(result)


@permission_required('newsletter.change_newsletter')
def send(request, id, test=False):
    newsletter = Newsletter.objects.get(id=id)
    subject = newsletter.name
    pm = Premailer(_newsletter_html(request, newsletter),
                   base_url=cyc_settings.CYCLOPE_BASE_URL,
                   preserve_internal_links=True,
                   )
    html_message = pm.transform()

    if test:
        recipients = map(strip, newsletter.test_recipients.split(','))
    else:
        recipients = map(strip, newsletter.recipients.split(','))

    if newsletter.sender_name:
        from_address = "%s <%s>" % (newsletter.sender_name, newsletter.sender)
    else:
        from_address = newsletter.sender

    msg = EmailMessage(subject, html_message, from_address, recipients)
    msg.content_subtype = "html"
    try:
        msg.send()
    except:
        logger = logging.getLogger("django.request")
        logger.exception("Newsletter send failed")
        return HttpResponseRedirect(reverse('newsletter_failed', args=[id]))
    else:
        return HttpResponseRedirect(reverse('newsletter_sent', args=[id]))

@permission_required('newsletter.change_newsletter')
def sent(request, id, test=False):
    t = loader.get_template("newsletter/mail_sent.html")
    newsletter = Newsletter.objects.get(id=id)
    c = RequestContext(request, {'newsletter': newsletter,})
    return HttpResponse(t.render(c))

@permission_required('newsletter.change_newsletter')
def failed(request, id, test=False):
    t = loader.get_template("newsletter/send_failed.html")
    newsletter = Newsletter.objects.get(id=id)
    c = RequestContext(request, {'newsletter': newsletter,})
    return HttpResponse(t.render(c))





# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'AbuseType'
        db.create_table('abuse_abusetype', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
        ))
        db.send_create_signal('abuse', ['AbuseType'])

        # Adding model 'AbuseReportElement'
        db.create_table('abuse_abusereportelement', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('abuse_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['abuse.AbuseType'])),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'])),
            ('date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('text', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('report', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['abuse.AbuseReport'])),
        ))
        db.send_create_signal('abuse', ['AbuseReportElement'])

        # Adding unique constraint on 'AbuseReportElement', fields ['user', 'content_type', 'object_id']
        db.create_unique('abuse_abusereportelement', ['user_id', 'content_type_id', 'object_id'])

        # Adding model 'AbuseReport'
        db.create_table('abuse_abusereport', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')()),
            ('status', self.gf('django.db.models.fields.CharField')(default='REP', max_length=4)),
        ))
        db.send_create_signal('abuse', ['AbuseReport'])


    def backwards(self, orm):
        
        # Removing unique constraint on 'AbuseReportElement', fields ['user', 'content_type', 'object_id']
        db.delete_unique('abuse_abusereportelement', ['user_id', 'content_type_id', 'object_id'])

        # Deleting model 'AbuseType'
        db.delete_table('abuse_abusetype')

        # Deleting model 'AbuseReportElement'
        db.delete_table('abuse_abusereportelement')

        # Deleting model 'AbuseReport'
        db.delete_table('abuse_abusereport')


    models = {
        'abuse.abusereport': {
            'Meta': {'object_name': 'AbuseReport'},
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'status': ('django.db.models.fields.CharField', [], {'default': "'REP'", 'max_length': '4'})
        },
        'abuse.abusereportelement': {
            'Meta': {'unique_together': "(('user', 'content_type', 'object_id'),)", 'object_name': 'AbuseReportElement'},
            'abuse_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['abuse.AbuseType']"}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'report': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['abuse.AbuseReport']"}),
            'text': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"})
        },
        'abuse.abusetype': {
            'Meta': {'object_name': 'AbuseType'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['abuse']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models
from django.contrib.contenttypes import generic
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.models import ContentType

from cyclope.models import BaseContent
from cyclope.core.collections.models import Collectible


class SeriesContent(models.Model):

    self_type = models.ForeignKey(ContentType, verbose_name=_('content type'),
                                  related_name='series_contents_lt')
    self_id = models.PositiveIntegerField(db_index=True)

    other_type = models.ForeignKey(ContentType, verbose_name=_('content type'),
                                     related_name='series_contents_rt')
    other_id = models.PositiveIntegerField(db_index=True)

    self_object = generic.GenericForeignKey(ct_field='self_type',
                                                  fk_field='self_id')
    other_object = generic.GenericForeignKey(ct_field='other_type',
                                                  fk_field='other_id')

    order = models.IntegerField(blank=True, null=True, db_index=True)

    def __unicode__(self):
        return self.other_object.name

    class Meta:
        verbose_name = _('series content')
        verbose_name_plural = _('series contents')
        ordering = ['order', ]


class Series(BaseContent, Collectible):
    """Base model for Series contents.

    """
    description = models.TextField(_('description'), blank=True)

    image = models.ImageField(_('image'), max_length=100,
                               blank=True, upload_to="uploads/series/")

    series_contents = generic.GenericRelation(SeriesContent,
                                              object_id_field='self_id',
                                              content_type_field='self_type')

    # models allowed as series content
    content_models = []
    _cache_content_types = None

    @classmethod
    def get_content_types(cls):
        if cls._cache_content_types is None:
            dic = ContentType.objects.get_for_models(*cls.content_models)
            cls._cache_content_types = dic.values()
        return cls._cache_content_types

    @classmethod
    def get_content_models(cls):
        return cls.content_models

    @classmethod
    def get_content_types_choices(cls):

        dic = ContentType.objects.get_for_models(*cls.content_models)
        ctype_choices = map(lambda item: (item[1].id, item[0]._meta.verbose_name),
                            dic.iteritems())
        ctype_choices.insert(0, ('', '------'))
        return sorted(ctype_choices, key=lambda choice: choice[1])

    def get_content_objects(self):
        return [sc.other_object for sc in self.series_contents.all()]

    class Meta:
        verbose_name = _('series')
        verbose_name_plural = _('series')
        ordering = ['-creation_date', ]
        abstract = True



from django.http import HttpResponse
from django.contrib.contenttypes.models import ContentType
from django.contrib.auth.decorators import user_passes_test
from django.core.exceptions import ObjectDoesNotExist

def staff_required(function=None):
    """
    Decorator for views that checks that the user is staff.
    """
    actual_decorator = user_passes_test(lambda u: u.is_staff)
    if function:
        return actual_decorator(function)
    return actual_decorator


def do_render_object(obj):
    data = []
    data.append('<div class="object-text-repr float-left">%s</div>' % unicode(obj))
    if hasattr(obj, "thumbnail"):
        try:
            data.append(obj.thumbnail())
        except (TypeError, AttributeError) as e:
            pass
    return " ".join(data)


@staff_required
def render_object(request, ct_id, obj_id):
    """
    Returns the html of an arbitrary object to display in the admin FK widget
    via ajax.
    """
    html = ""
    try:
        obj = ContentType.objects.get_for_id(ct_id).get_object_for_this_type(pk=obj_id)
        html = do_render_object(obj)
    except ObjectDoesNotExist:
        pass
    return HttpResponse(html)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from cyclope.default_settings import *
import os

DEBUG = True
TEMPLATE_DEBUG = DEBUG

CYCLOPE_PROJECT_PATH = os.path.dirname(__file__)

INTERNAL_IPS = ('127.0.0.1',)

#ADMINS = (('Your Name', 'your_email@domain.com'),)

#MANAGERS = (('Your Name', 'your_email@domain.com'), )

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(CYCLOPE_PROJECT_PATH, 'db/site.db'),
    }
}

TIME_ZONE = 'America/Argentina/Buenos_Aires'

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = os.path.join(CYCLOPE_PROJECT_PATH, 'media/')

STATIC_ROOT = os.path.join(CYCLOPE_PROJECT_PATH, 'media/')

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash if there is a path component (optional in other cases).
# Examples: "http://media.lawrence.com", "http://example.com/media/"
MEDIA_URL = '/media/'

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/media/'

ROOT_URLCONF = '{{ project_name }}.urls'

TEMPLATE_DIRS = (
    # Put strings here, like "/home/html/django_templates".
    # Don't forget to use absolute paths, not relative paths.
    os.path.join(CYCLOPE_PROJECT_PATH, 'templates'),
)

LOCALE_PATHS = (
    os.path.join(CYCLOPE_PROJECT_PATH, 'locale'),
)

INSTALLED_APPS += (
    '{{ project_name }}',
)

LOGIN_REDIRECT_URL = '/inicio'


# Add real email account setup here for registration to work properly.

# The host to use for sending e-mail. Default: 'localhost'
#EMAIL_HOST='smtp.gmail.com'

# Username to use for the SMTP server defined in EMAIL_HOST. If empty,
# Django won't attempt authentication. Default: '' (Empty string)
#EMAIL_HOST_USER='anon.email.noreply'

# Password to use for the SMTP server defined in EMAIL_HOST. This setting
# is used in conjunction with EMAIL_HOST_USER when authenticating to the
# SMTP server. If either of these settings is empty, Django won't attempt
# authentication. Default: '' (Empty string)
#EMAIL_HOST_PASSWORD='anon.email'

# Port to use for the SMTP server defined in EMAIL_HOST. Default: 25
#EMAIL_PORT='587'

# Default e-mail address to use for various automated correspondence from
# the site manager(s). Default: 'webmaster@localhost'
#DEFAULT_FROM_EMAIL = ""

# The e-mail address that error messages come from, such as those sent to
# ADMINS and MANAGERS. Default: 'root@localhost'
#SERVER_EMAIL = ""

# Whether to use a TLS (secure) connection when talking to the SMTP server.
# Default: False
#EMAIL_USE_TLS = True  # we set this to True for the sample email config

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    }
}


# Cyclope settings

#CYCLOPE_LOCAL_THEMES_DIR = os.path.join(CYCLOPE_PROJECT_PATH, 'templates/cyclope/themes/')
#CYCLOPE_LOCAL_THEMES_MEDIA_PREFIX = '/media/local_themes/'

CYCLOPE_PREFIX = ''

#CYCLOPE_CONTACTS_PROFILE_MODULE = "app.model"
#CYCLOPE_CONTACTS_PROFILE_ADMIN_INLINE_MODULE = "project.app.admin.ProfileModuleInline"
#CYCLOPE_CONTACTS_PROFILE_TEMPLATE = "app/profile_template.html"

# possible values for TEXT_STYLE are:
# textile (saves markup, renders with corresponding filter)
# wysiwyg (rich text editor, saves HTML, renders with safe filter)
# raw (simple text area saves the raw input, renders with safe filter)

CYCLOPE_TEXT_STYLE = 'textile'

#CYCLOPE_PAGINATION = {'TEASER' : 3, 'LABELED_ICON' : 5,
#                      'FORUM' : 2, 'DETAIL': 5}

HAYSTACK_SITECONF = '{{ project_name }}.search_sites'
HAYSTACK_WHOOSH_PATH = os.path.join(CYCLOPE_PROJECT_PATH, 'cyclope_project_index')

#FILEBROWSER_MAX_UPLOAD_SIZE = 1024*1024*20 # 20MB

# Make this unique, and don't share it with anybody.
SECRET_KEY = '{{ secret_key }}'



# *-- coding:utf-8 --*
"""Configuration for the Neutrona theme templates and regions.

Attributes:
    verbose_name: name of theme to be displayed in the admin interface
    layout_templates: dictionary defining regions for the available templates
"""

from django.utils.translation import ugettext_lazy as _

verbose_name = _('Cyportal')

layout_templates = {

    'four_elements.html':
        {
        'verbose_name': _('FourElements'),
        'regions' : {
            'air': _('Air'),
            'water': _('Water'),
            'spark': _('Spark'),
            'ash': _('Ash'),
            'earth': _('Earth'),
            }
        },

    'five_elements.html':
        {
        'verbose_name': _('FiveElements'),
        'regions' : {
            'air': _('Air'),
            'water': _('Water'),
            'love': _('Love'),
            'spark': _('Spark'),
            'ash': _('Ash'),
            'earth': _('Earth'),
            }
        },
    'empty.html':
        {'verbose_name': _('Empty'),
         'regions': {}
         },

    'newsletter.html':
        {'verbose_name': _('Newsletter'),
        'regions' : {
            'header': _('header'),
            'before_content': _('before content'),
            'after_content': _('after content'),
            }
         },
}



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Copyright 2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from autoslug.fields import AutoSlugField
from registration import signals as registration_signals

class UserProfile(models.Model):
    user = models.ForeignKey(User, unique=True)
    slug = AutoSlugField(populate_from=lambda obj:obj.user.username, unique=True,
                         null=False, db_index=True)
    avatar = models.ImageField(_('avatar'), max_length=100,
                               blank=True, upload_to="uploads/avatars/")
    city = models.CharField(_('city'), max_length=100, blank=True)
    about = models.TextField(_('about myself'), max_length=1000, blank=True)

    public = models.BooleanField(
        _('public'), default=True,
        help_text=_('Choose whether your profile info should be publicly visible or not'))

    @models.permalink
    def get_absolute_url(self):
        return ('userprofile-detail', (), { 'slug': self.slug })

    def __unicode__(self):
        return self.user.get_full_name() or self.user.username

    def save(self, *args, **kwargs):
        super(UserProfile, self).save(*args, **kwargs)
        # This is a hack to deal with profiles that aren't created automatically by a signal
        # so the user is not part of the profile instance in the save method
        # Instead, the form save is issued from the profile model
        form = getattr(self, "_form", None)
        if form:
            form.instance = self
            form.save()

User.get_absolute_url = lambda self: self.get_profile().get_absolute_url()

# Signal callbacks

def _create_profile_upon_activation(*args, **kwargs):
    UserProfile.objects.create(user=kwargs['user'])

registration_signals.user_activated.connect(_create_profile_upon_activation)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


"""
admin
-----
configuration for the Django admin
"""

from django.db import models
from django.contrib import admin
from django.core import urlresolvers
from django.contrib.admin.options import FORMFIELD_FOR_DBFIELD_DEFAULTS
from django.utils.translation import ugettext_lazy as _
from django.http import HttpResponseRedirect
from django.contrib.sites.models import Site

from mptt_tree_editor.admin import TreeEditor

from cyclope.models import *
from cyclope.forms import MenuItemAdminForm,\
                          SiteSettingsAdminForm,\
                          LayoutAdminForm,\
                          RegionViewInlineForm,\
                          RelatedContentForm,\
                          AuthorAdminForm

from cyclope.widgets import get_default_text_widget
from cyclope.core.collections.admin import CollectibleAdmin
from cyclope.core.collections.models import Category
import cyclope.settings as cyc_settings
from cyclope.utils import PermanentFilterMixin

# Set default widget for all admin textareas
default_admin_textfield = FORMFIELD_FOR_DBFIELD_DEFAULTS[models.TextField]
default_admin_textfield['widget'] = get_default_text_widget()

class RelatedContentInline(generic.GenericStackedInline):
    form = RelatedContentForm
    ct_field = 'self_type'
    ct_fk_field = 'self_id'
    model = RelatedContent
    extra = 0


class BaseContentAdmin(admin.ModelAdmin):
    """Base class for content models to use instead of admin.ModelAdmin
    """
    inlines = [RelatedContentInline]
    date_hierarchy = 'creation_date'

    class Media:
        js = (
            cyc_settings.CYCLOPE_STATIC_URL + 'js/reuse_django_jquery.js',
            cyc_settings.CYCLOPE_STATIC_URL + 'js/jquery-ui-1.8.4.custom.min.js',
        )

    def response_change(self, request, obj):
        if '_frontend' in request.REQUEST:
            return HttpResponseRedirect(obj.get_absolute_url())
        return super(BaseContentAdmin, self).response_change(request, obj)

    def response_add(self, request, obj, post_url_continue='../%s/'):
        if '_frontend' in request.REQUEST:
            return HttpResponseRedirect(obj.get_absolute_url())
        return super(BaseContentAdmin, self).response_add(request, obj, post_url_continue)

    def has_delete_permission(self, request, obj=None):
        # this is redundant with _popup, which already sets delete_permission to False
        if '_frontend' in request.REQUEST:
            return False
        return super(BaseContentAdmin, self).has_delete_permission(request, obj)

    def change_view(self, request, object_id, form_url="", extra_context=None):
        if '_frontend' in request.REQUEST:
            if extra_context is None:
                extra_context = {}
            extra_context['frontend_admin'] = 'frontend_admin'

        return super(BaseContentAdmin, self).change_view(request, object_id,
                                                          form_url, extra_context)

    def add_view(self, request, form_url='', extra_context=None):
        if '_frontend' in request.REQUEST:
            if extra_context is None:
                extra_context = {}
            extra_context['frontend_admin'] = 'frontend_admin'
        if '_from_category' in request.REQUEST:
            ## TODO(nicoechaniz): this could be used to set the categorization, but is not implemented yet
            category_slug = request.REQUEST['_from_category']
            category = Category.objects.get(slug=category_slug)
            extra_context['initial_category'] = category.id
            extra_context['initial_collection'] = category.collection.id
        return super(BaseContentAdmin, self).add_view(request, form_url, extra_context)

    def save_model(self, request, obj, form, change):
        # sets the user as the creator of the content
        if getattr(obj, 'user', None) is None:
            obj.user = request.user
        obj.save()


class MenuItemAdmin(TreeEditor, PermanentFilterMixin):
    form = MenuItemAdminForm
    fieldsets = ((None,
                  {'fields': ('menu', 'parent', 'name', 'slug', 'site_home', 'active')}),
                 (_('content details'),
                  {'fields':('custom_url', 'content_type', 'content_view',
                             'view_options', 'content_object',),
                  'description': _(u"Either set an URL here or select a content"
                                    "type and view.")
                  }),
                 (_('layout'),
                  {'fields':('layout', 'persistent_layout'),
                   'classes': ('collapse',),
                   'description': _(u"Set the layout that will be used when this "
                                    "menuitem is selected.")
                   }),
                )
    list_filter = ('menu',)

    permanent_filters = (
        (u"menu__id__exact",
         lambda request: unicode(Menu.objects.all()[0].id)),
    )

    def changelist_view(self, request, extra_context=None):
        self.do_permanent_filters(request)
        return super(MenuItemAdmin, self).changelist_view(request, extra_context)

admin.site.register(MenuItem, MenuItemAdmin)
admin.site.register(Menu)


class RegionViewInline(admin.StackedInline):
    form = RegionViewInlineForm
    model = RegionView
    extra = 1


class LayoutAdmin(admin.ModelAdmin):
    form = LayoutAdminForm
    inlines = (RegionViewInline, )

admin.site.register(Layout, LayoutAdmin)


class SiteSettingsAdmin(admin.ModelAdmin):
    form = SiteSettingsAdminForm

    def has_add_permission(self, request):
        """ Prevent addition of new objects """
        return False

    def has_delete_permission(self, request, obj=None):
        return False

admin.site.register(SiteSettings, SiteSettingsAdmin)

class ImageAdmin(admin.ModelAdmin):
    list_display = ['thumbnail']

admin.site.register(Image, ImageAdmin)

class AuthorAdmin(admin.ModelAdmin):
    form = AuthorAdminForm
    list_display = ('name', 'thumbnail')
    search_fields = ('name', 'origin', 'notes')

admin.site.register(Author, AuthorAdmin)

admin.site.register(Source)

class SiteAdmin(admin.ModelAdmin):
    list_display = ('domain', 'name')
    search_fields = ('domain', 'name')

    def has_add_permission(self, request):
        """ Prevent addition of new objects """
        return False

    def has_delete_permission(self, request, obj=None):
        return False



import django.contrib.sites.admin # Force register of django's SiteAdmin
admin.site.unregister(Site)
admin.site.register(Site, SiteAdmin)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
fields
------
"""

from django import forms
from django.core.exceptions import ValidationError

from cyclope.widgets import MultipleWidget

class MultipleField(forms.Field):
    def __init__(self, form=None, *args, **kwargs):
        """
        Field containing multiple fields that are gathered from a form that could
        be a forms.Form instance, a forms.Form class or None.
        """
        super(MultipleField, self).__init__(*args, **kwargs)
        if form is None:
            self.fields = {}
        else:
            if not hasattr(form, "fields"):
                form = form()
            self.fields = form.fields
        self.widget = MultipleWidget(self.fields)
        kwargs.setdefault('help_text', "")
        self.initial = {}
        for field_name, field in self.fields.iteritems():
            self.initial[field_name] = field.initial

    def prepare_value(self, value):
        initial = self.initial.copy()
        initial.update(value)
        return initial

    def to_python(self, value):
        if value is None:
            return
        fields = self.fields.copy()
        errors = []
        for value_name in value:
            try:
                fields[value_name] = fields[value_name].clean(value[value_name])
            except ValidationError, e:
                if hasattr(e, 'code') and e.code in self.error_messages:
                    message = self.error_messages[e.code]
                    if e.params:
                        message = message % e.params
                    errors.append(message)
                else:
                    errors.extend(e.messages)
        if errors:
            raise ValidationError(errors)
        return fields

    def clean(self, value, validate=False):
        """
        Validates the given value and returns its "cleaned" value as an
        appropriate Python object.

        Raises ValidationError for any errors.
        """
        if not validate:
            value = {}
        else:
            value = self.to_python(value)
            self.validate(value)
            self.run_validators(value)
        return value



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.utils.translation import ugettext_lazy as _

from cyclope.core import frontend
from cyclope import views

from models import StaticPage, HTMLBlock


class StaticPageDetail(frontend.FrontendView):
    """Detail view of a StaticPage.

    Returns:
        a string if the view is called from within a region templatetag
        an HttpResponse otherwise
    """
    name = 'detail'
    verbose_name = _('detailed view of the selected Static Page')
    is_default = True
    is_content_view = True
    is_region_view = True

    def get_response(self, request, req_context, options, content_object):
        return views.object_detail(request, req_context, content_object)

frontend.site.register_view(StaticPage, StaticPageDetail)


class StaticPageList(frontend.FrontendView):
    """Simple list view for StaticPages.
    """
    name = 'list'
    verbose_name = _('list of Static Pages')
    is_instance_view = False
    is_content_view = True
    is_region_view = True

    def get_response(self, request, req_context, options):
        return views.object_list(request, req_context, StaticPage.objects.all())

frontend.site.register_view(StaticPage, StaticPageList)


class HTMLBlockDetail(frontend.FrontendView):
    """Detail view of a HTMLBlock.

    Returns:
        a string if the view is called from within a region templatetag
        an HttpResponse otherwise
    """
    name = 'detail'
    verbose_name = _('display the selected HTML Block')
    is_default = True
    is_region_view = True
    is_content_view = True

    def get_response(self, request, req_context, options, content_object):
        return views.object_detail(request, req_context, content_object)

frontend.site.register_view(HTMLBlock, HTMLBlockDetail)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2012 Código Sur Asociación Civil
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
core.perms.backends
-------------------
Authorizacion backends.
"""

from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from django.contrib.auth.models import User

from cyclope.core.collections.models import Categorization, Collectible, Category
from models import CategoryPermission


class CategoryPermBackend(object):
    supports_object_permissions = True
    supports_anonymous_user = False
    supports_inactive_user = False

    def authenticate(self, username, password):
        return None

    def _get_all_permissions(self, user_obj, obj=None):
        """Returns a queryset of all CategoryPermissions a user has over a Category or Collectible"""
        if obj is None or not user_obj.is_authenticated() or not user_obj.is_active:
            return CategoryPermission.objects.none()
        if issubclass(obj.__class__, Collectible):
            categorizations = Categorization.objects.get_for_object(obj)
            categories = [ c.category for c in categorizations ]
        elif issubclass(obj.__class__, Category):
            categories = [obj]
        return CategoryPermission.objects.filter(category__in=categories, user=user_obj)

    def get_all_permissions(self, user_obj, obj=None):
        """Returns a dictionary of permissions a user has over a Category or Collectible"""
        permissions = self._get_all_permissions(user_obj, obj)
        perms_dict = {}
        if permissions:
            for perm in ['edit_content', 'add_content']:
                perms_dict[perm] = permissions.filter(**{'can_%s' % perm: True}).exists()
        return perms_dict

    def has_perm(self, user_obj, perm, obj=None):
        if obj is None:
            return False

        permissions = self._get_all_permissions(user_obj, obj)
        return permissions.filter(**{'can_%s' % perm: True}).exists()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


"""
apps.contacts.models
--------------------
"""

from django.db import models
from django.utils.translation import ugettext_lazy as _

from cyclope.models import BaseContent
from cyclope.core.collections.models import Collectible


class Country(models.Model):
    name = models.CharField(_('name'), max_length=255)

    def __unicode__(self):
        return self.name

class Region(models.Model):
    country = models.ForeignKey(Country)
    name = models.CharField(_('name'), max_length=255)

    def __unicode__(self):
        return self.name

class City(models.Model):
    region = models.ForeignKey(Region)
    name = models.CharField(_('name'), max_length=255)

    def __unicode__(self):
        return self.name

class Location(models.Model):
    country = models.ForeignKey(Country, verbose_name=_('country'),blank=True, null=True)
    region = models.ForeignKey(Region, verbose_name=_('region'), blank=True, null=True)
    city = models.ForeignKey(City, verbose_name=_('city'), blank=True, null=True)
    zip_code = models.CharField(_('zip code'), blank=True, max_length=15)
    street_address = models.CharField(_('street address'), blank=True, max_length=255)
    phone_number = models.CharField(max_length=40, verbose_name=_('phone number'), blank=True)
    post_office_box = models.CharField(_('postal box'), blank=True, max_length=255)

    class Meta:
        abstract = True

    def __unicode__(self):
        return "%s, %s %s, %s, %s" % (self.street_address if self.street_address else '',
                                    self.city if self.city else '',
                                    '(%s)' % self.zip_code if self.zip_code else '',
                                    self.region if self.region else '',
                                    self.country if self.country else '',)
    






#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):

        # Adding model 'Collection'
        db.create_table('collections_collection', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(unique=True, max_length=50)),
            ('slug', self.gf('autoslug.fields.AutoSlugField')(unique_with=(), max_length=50, populate_from=None, db_index=True)),
            ('visible', self.gf('django.db.models.fields.BooleanField')(default=True, blank=True)),
            ('navigation_root', self.gf('django.db.models.fields.BooleanField')(default=False, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('image', self.gf('filebrowser.fields.FileBrowseField')(max_length=250, blank=True)),
        ))
        db.send_create_signal('collections', ['Collection'])

        # Adding M2M table for field content_types on 'Collection'
        db.create_table('collections_collection_content_types', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('collection', models.ForeignKey(orm['collections.collection'], null=False)),
            ('contenttype', models.ForeignKey(orm['contenttypes.contenttype'], null=False))
        ))
        db.create_unique('collections_collection_content_types', ['collection_id', 'contenttype_id'])

        # Adding model 'Category'
        db.create_table('collections_category', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('collection', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'collection categories', to=orm['collections.Collection'])),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=50)),
            ('slug', self.gf('autoslug.fields.AutoSlugField')(unique_with=(), max_length=50, populate_from=None, db_index=True)),
            ('parent', self.gf('django.db.models.fields.related.ForeignKey')(blank=True, related_name=u'children', null=True, to=orm['collections.Category'])),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True, db_index=True, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('image', self.gf('filebrowser.fields.FileBrowseField')(max_length=250, blank=True)),
            ('lft', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('rght', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('tree_id', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
            ('level', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
        ))
        db.send_create_signal('collections', ['Category'])

        # Adding unique constraint on 'Category', fields ['collection', 'name']
        db.create_unique('collections_category', ['collection_id', 'name'])

        # Adding model 'CategoryMap'
        db.create_table('collections_categorymap', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('category', self.gf('django.db.models.fields.related.ForeignKey')(related_name='category_maps', to=orm['collections.Category'])),
            ('content_type', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contenttypes.ContentType'])),
            ('object_id', self.gf('django.db.models.fields.PositiveIntegerField')(db_index=True)),
        ))
        db.send_create_signal('collections', ['CategoryMap'])


    def backwards(self, orm):

        # Deleting model 'Collection'
        db.delete_table('collections_collection')

        # Removing M2M table for field content_types on 'Collection'
        db.delete_table('collections_collection_content_types')

        # Deleting model 'Category'
        db.delete_table('collections_category')

        # Removing unique constraint on 'Category', fields ['collection', 'name']
        db.delete_unique('collections_category', ['collection_id', 'name'])

        # Deleting model 'CategoryMap'
        db.delete_table('collections_categorymap')


    models = {
        'collections.category': {
            'Meta': {'unique_together': "(('collection', 'name'),)", 'object_name': 'Category'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True', 'blank': 'True'}),
            'collection': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'collection categories'", 'to': "orm['collections.Collection']"}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "u'children'", 'null': 'True', 'to': "orm['collections.Category']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.categorymap': {
            'Meta': {'object_name': 'CategoryMap'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'category_maps'", 'to': "orm['collections.Category']"}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.collection': {
            'Meta': {'object_name': 'Collection'},
            'content_types': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['contenttypes.ContentType']", 'db_index': 'True', 'symmetrical': 'False'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50'}),
            'navigation_root': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'visible': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['collections']



from django.conf import settings
from django.core import mail
from django.test import TestCase
from django.db import IntegrityError
from django.contrib.auth.models import User
from django.contrib.contenttypes.models import ContentType
from django.core.urlresolvers import reverse
from django.contrib.sites.models import Site
from django.contrib import comments
from django.contrib.comments import signals
from django.test.client import RequestFactory

from forms import CustomCommentForm
from models import CustomComment
import models as custom_comment_models
from moderator import CustomCommentModerator, moderator

moderator.register(Site, CustomCommentModerator)

class CustomCommentTest(TestCase):

    def setUp(self):
        self.site = Site.objects.all()[0]
        self.site.name = "TestSite"
        self.site.domain = "example.com"
        self.site.save()
        settings.MANAGERS = ('Manager', 'manager@test.org',)

    def test_suscribe(self):
        CustomComment.moderation_enabled = lambda x:True
        comment = self.create_comment()
        # mail sent to moderators only
        self.assertEqual(len(mail.outbox), 1)
        self.assertTrue("New comment posted on '%s'" % self.site in mail.outbox[0].subject)

        other_comment = self.create_comment()

        reply = CustomComment(name="SAn AE", email="san-ae@test.com", parent=comment,
                              content_object=self.site, site=self.site, subscribe=True)
        reply.save()

        # mail sent to moderators and to original author of first comment
        self.assertEqual(len(mail.outbox), 4)
        self.assertEqual(mail.outbox[3].to[0], "san@test.com")

    def test_needs_moderation(self):
        custom_comment_models.moderation_enabled = lambda :False
        self.create_comment()
        self.assertEqual(len(CustomComment.objects.in_moderation()), 0)
        custom_comment_models.moderation_enabled = lambda :True
        self.create_comment()
        self.assertEqual(len(CustomComment.objects.in_moderation()), 1)

    def create_comment(self):
        comment = CustomComment(name="SAn", email="san@test.com", parent=None,
                                content_object=self.site, site=self.site,
                                subscribe=True)

        request = RequestFactory().get('/')

        # Signal that the comment is about to be saved
        responses = signals.comment_will_be_posted.send(
            sender  = comment.__class__,
            comment = comment,
            request = request
        )

        for (receiver, response) in responses:
            if response == False:
                return

        # Save the comment and signal that it was saved
        comment.save()
        signals.comment_was_posted.send(
            sender  = comment.__class__,
            comment = comment,
            request = request
        )
        comment.save()
        return comment




#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.utils import simplejson as json

from django.http import HttpResponse

from models import Region, Country, City

def _make_choices(query_set):
    choices = [{'object_id': '', 'verbose_name': '------'}]
    choices.extend([{'object_id': model.id, 'verbose_name': unicode(model)}
                           for model in query_set])
    return choices

def regions_list(request):
    country_id = int(request.GET['q'])
    query_set = Region.objects.filter(country__id = country_id)
    json_data = json.dumps(_make_choices(query_set))
    return HttpResponse(json_data, mimetype = 'application/javascript')

def cities_list(request):
    region_id = int(request.GET['q'])
    query_set = City.objects.filter(region__id = region_id)
    json_data = json.dumps(_make_choices(query_set))
    return HttpResponse(json_data, mimetype = 'application/javascript')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


from django.utils.translation import ugettext_lazy as _

from cyclope.core import frontend
from cyclope import views

from models import Location


#class LocationDetail(frontend.FrontendView):
    #"""Detail view for Locations"""
    #name='detail'
    #verbose_name=_('detailed view of the selected Location')
    #is_default = True
    #is_instance_view = True
    #is_content_view = True

    #def get_response(self, request, req_context, content_object):
        #context = {'content_relations': content_object.related_contents.all()}
        #return views.object_detail(request, req_context, content_object,
                                   #extra_context=context)

#frontend.site.register_view(Location, LocationDetail)


#class LocationTeaserList(frontend.FrontendView):
    #"""Teaser list view for Locations.
    #"""
    #name='teaser_list'
    #verbose_name=_('list of Location teasers')
    #is_instance_view = False
    #is_content_view = True
    #is_region_view = True

    #def get_response(self, request, req_context):
        #return views.object_list(request, req_context,
                                 #Location.objects.all(), view_name=self.name)


#frontend.site.register_view(Location, LocationTeaserList)



from django.test import TestCase
from django.db import IntegrityError
from django.contrib.auth.models import User
from django.contrib.contenttypes.models import ContentType
from django.core.urlresolvers import reverse


import models
from models import AbuseType, AbuseReport, AbuseReportElement
from . import register

register(AbuseType)

class AbuseReportTest(TestCase):
    def setUp(self):
        # Fake sending email
        self.subject, self.message, self.mail_sent = "", "", False

        def mail_managers_fake(subject, message, fail_silently):
            self.subject = subject
            self.message = message
            self.mail_sent = True

        models.mail_managers = mail_managers_fake

        self.abused_object = AbuseType.objects.create(name="abused-object")


        abuse_type = AbuseType.objects.create(name="copyright")
        self.user = User.objects.create_user('john', 'lennon@thebeatles.com',
                                        'johnpassword')

        report_el = AbuseReportElement(abuse_type=abuse_type, user=self.user,
                                       text="Texto del reporte",
                                       content_object=self.abused_object)
        report_el.save()

        self.report_el = report_el
        self.abuse_type = abuse_type

    def test_create_report_element(self):
        self.assertEqual(len(AbuseReport.objects.all()), 1)

    def test_change_status_to_deleted(self):
        report = AbuseReport.objects.get()
        report.status = 'DEL'
        report.save()
        self.assertFalse(AbuseType.objects.filter(name='abused-object').exists())
        report.save()

    def test_send_mail_on_report(self):
        self.assertTrue('abused-object' in self.message)

        report = AbuseReport.objects.get()
        report.status = 'IGN'
        report.save()

        self.mail_sent = False
        other_user = User.objects.create_user('john2', 'lennon@thebeatles.com',
                                              'johnpassword')
        report_el = AbuseReportElement(abuse_type=self.abuse_type,
                                       user=other_user,
                                       text="Texto del reporte 2",
                                       content_object=self.abused_object)
        report_el.save()
        self.assertFalse(self.mail_sent)

    def test_report_abuse(self):
        ct_id = ContentType.objects.get_for_model(self.abused_object).pk
        obj_id = self.abused_object.pk
        self.client.login(username='john', password='johnpassword')
        response = self.client.post(reverse("abuse-report", args=(ct_id, obj_id)))
        self.assertEqual(response.status_code, 200)

    def test_report_loged_in(self):
        ct_id = ContentType.objects.get_for_model(self.abused_object).pk
        obj_id = self.abused_object.pk
        response = self.client.get(reverse("abuse-report", args=(ct_id, obj_id)))
        self.assertEqual(response.status_code, 302)
        self.client.login(username='john', password='johnpassword')
        response = self.client.get(reverse("abuse-report", args=(ct_id, obj_id)))
        self.assertEqual(response.status_code, 200)

    def test_unique_user_report_for_object(self):
        report_el = AbuseReportElement(abuse_type=self.abuse_type,
                                       user=self.user,
                                       text="Texto del reporte 2",
                                       content_object=self.abused_object)

        self.assertRaises(IntegrityError, report_el.save)





#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010-2012 Código Sur Sociedad Civil.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.utils.translation import ugettext_lazy as _

from cyclope.core import frontend
from cyclope import views
from cyclope import settings as cyc_settings

from models import Series


class SeriesDetail(frontend.FrontendView):
    """Detail view for Series"""
    name='detail'
    verbose_name=_('detailed view of the selected Series')
    is_default = True
    is_instance_view = True
    is_content_view = True
    is_region_view = True

    def get_response(self, request, req_context, options, content_object):
        return views.object_detail(request, req_context, content_object)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


"""
apps.contacts.models
--------------------
"""

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.core.exceptions import ImproperlyConfigured
from django.contrib.auth.models import User, SiteProfileNotAvailable

from cyclope.models import BaseContent
from cyclope.core.collections.models import Collectible

from cyclope.apps.locations.models import Location
from autoslug.fields import AutoSlugField
from filebrowser.fields import FileBrowseField

ADDRESS_TYPE_CHOICES = (
    ('WORK', _('work')),
    ('HOME', _('home')),
)

class ContactAddress(Location):
    type = models.CharField(_('type'), max_length=20, choices=ADDRESS_TYPE_CHOICES)
    contact = models.ForeignKey("Contact", verbose_name=_('contact'))

    class Meta:
        verbose_name = _('contact address')
        verbose_name_plural = _('contact addresses')

GENDER_CHOICES = (('M', _('Male')),('F', _('Female')))

class Contact(BaseContent, Collectible):
    given_name = models.CharField(_('given name'), max_length=255)
    surname = models.CharField(_('surname'), blank=True, max_length=255)
    birth_date = models.DateField(_('birth date'), blank=True, null=True)
    gender = models.CharField(_('gender'), max_length=1, choices=GENDER_CHOICES, null=True, blank=True)
    photo = FileBrowseField(_('photo'), max_length=100, format='Image',
                            directory='contact_images/', blank=True)
    email = models.EmailField(_('e-mail'), blank=True)
    web = models.CharField(_('web site'), max_length=255, blank=True)
    mobile_phone_number = models.CharField(_('mobile phone number'), max_length=40, blank=True)

    class Meta:
        verbose_name = _('contact')
        verbose_name_plural = _('contacts')

    def __unicode__(self):
        return self.get_full_name()

    def save(self, *args, **kwargs):
        self.name = unicode(self)
        super(BaseContent, self).save(*args, **kwargs)
        super(Collectible, self).save(*args, **kwargs)

    def get_full_name(self):
        "Returns the first_name plus the last_name, with a space in between."
        full_name = self.given_name
        if self.surname:
            full_name += u" %s" % self.surname
        return full_name.strip()

    def get_profile(self):
        """
        Returns site-specific profile for this contact. Raises
        SiteProfileNotAvailable if this site does not allow profiles.
        """
        if not hasattr(self, '_profile_cache'):
            from django.conf import settings
            if not getattr(settings, 'CYCLOPE_CONTACTS_PROFILE_MODULE', False):
                raise SiteProfileNotAvailable('You need to set CYCLOPE_CONTACTS'
                                              '_PROFILE_MODULE in your project settings')
            try:
                app_label, model_name = settings.CYCLOPE_CONTACTS_PROFILE_MODULE.split('.')
            except ValueError:
                raise SiteProfileNotAvailable('app_label and model_name should'
                        ' be separated by a dot in the CYCLOPE_CONTACTS_PROFILE'
                        '_MODULE setting')

            try:
                model = models.get_model(app_label, model_name)
                if model is None:
                    raise SiteProfileNotAvailable('Unable to load the profile '
                        'model, check CYCLOPE_CONTACTS_PROFILE_MODULE in your '
                        'project settings')
                self._profile_cache = model._default_manager.using(self._state.db).get(contact__id__exact=self.id)
                self._profile_cache.user = self
            except (ImportError, ImproperlyConfigured):
                raise SiteProfileNotAvailable
        return self._profile_cache

    def has_profile(self):
        """
        Returns True if contacts are extended with a profile.
        """
        from django.conf import settings
        if not getattr(settings, 'CYCLOPE_CONTACTS_PROFILE_MODULE', False):
            return False
        return True




# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding field 'RegularFile.creation_date'
        db.add_column('medialibrary_regularfile', 'creation_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now_add=True, blank=True), keep_default=False)

        # Adding field 'RegularFile.modification_date'
        db.add_column('medialibrary_regularfile', 'modification_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now=True, blank=True), keep_default=False)

        # Adding field 'RegularFile.allow_comments'
        db.add_column('medialibrary_regularfile', 'allow_comments', self.gf('django.db.models.fields.CharField')(default='SITE', max_length=4), keep_default=False)

        # Adding field 'MovieClip.creation_date'
        db.add_column('medialibrary_movieclip', 'creation_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now_add=True, blank=True), keep_default=False)

        # Adding field 'MovieClip.modification_date'
        db.add_column('medialibrary_movieclip', 'modification_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now=True, blank=True), keep_default=False)

        # Adding field 'MovieClip.allow_comments'
        db.add_column('medialibrary_movieclip', 'allow_comments', self.gf('django.db.models.fields.CharField')(default='SITE', max_length=4), keep_default=False)

        # Adding field 'FlashMovie.creation_date'
        db.add_column('medialibrary_flashmovie', 'creation_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now_add=True, blank=True), keep_default=False)

        # Adding field 'FlashMovie.modification_date'
        db.add_column('medialibrary_flashmovie', 'modification_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now=True, blank=True), keep_default=False)

        # Adding field 'FlashMovie.allow_comments'
        db.add_column('medialibrary_flashmovie', 'allow_comments', self.gf('django.db.models.fields.CharField')(default='SITE', max_length=4), keep_default=False)

        # Adding field 'Document.creation_date'
        db.add_column('medialibrary_document', 'creation_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now_add=True, blank=True), keep_default=False)

        # Adding field 'Document.modification_date'
        db.add_column('medialibrary_document', 'modification_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now=True, blank=True), keep_default=False)

        # Adding field 'Document.allow_comments'
        db.add_column('medialibrary_document', 'allow_comments', self.gf('django.db.models.fields.CharField')(default='SITE', max_length=4), keep_default=False)

        # Adding field 'ExternalContent.creation_date'
        db.add_column('medialibrary_externalcontent', 'creation_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now_add=True, blank=True), keep_default=False)

        # Adding field 'ExternalContent.modification_date'
        db.add_column('medialibrary_externalcontent', 'modification_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now=True, blank=True), keep_default=False)

        # Adding field 'ExternalContent.allow_comments'
        db.add_column('medialibrary_externalcontent', 'allow_comments', self.gf('django.db.models.fields.CharField')(default='SITE', max_length=4), keep_default=False)

        # Adding field 'SoundTrack.creation_date'
        db.add_column('medialibrary_soundtrack', 'creation_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now_add=True, blank=True), keep_default=False)

        # Adding field 'SoundTrack.modification_date'
        db.add_column('medialibrary_soundtrack', 'modification_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now=True, blank=True), keep_default=False)

        # Adding field 'SoundTrack.allow_comments'
        db.add_column('medialibrary_soundtrack', 'allow_comments', self.gf('django.db.models.fields.CharField')(default='SITE', max_length=4), keep_default=False)

        # Adding field 'Picture.creation_date'
        db.add_column('medialibrary_picture', 'creation_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now_add=True, blank=True), keep_default=False)

        # Adding field 'Picture.modification_date'
        db.add_column('medialibrary_picture', 'modification_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime.now(), auto_now=True, blank=True), keep_default=False)

        # Adding field 'Picture.allow_comments'
        db.add_column('medialibrary_picture', 'allow_comments', self.gf('django.db.models.fields.CharField')(default='SITE', max_length=4), keep_default=False)


    def backwards(self, orm):
        
        # Deleting field 'RegularFile.creation_date'
        db.delete_column('medialibrary_regularfile', 'creation_date')

        # Deleting field 'RegularFile.modification_date'
        db.delete_column('medialibrary_regularfile', 'modification_date')

        # Deleting field 'RegularFile.allow_comments'
        db.delete_column('medialibrary_regularfile', 'allow_comments')

        # Deleting field 'MovieClip.creation_date'
        db.delete_column('medialibrary_movieclip', 'creation_date')

        # Deleting field 'MovieClip.modification_date'
        db.delete_column('medialibrary_movieclip', 'modification_date')

        # Deleting field 'MovieClip.allow_comments'
        db.delete_column('medialibrary_movieclip', 'allow_comments')

        # Deleting field 'FlashMovie.creation_date'
        db.delete_column('medialibrary_flashmovie', 'creation_date')

        # Deleting field 'FlashMovie.modification_date'
        db.delete_column('medialibrary_flashmovie', 'modification_date')

        # Deleting field 'FlashMovie.allow_comments'
        db.delete_column('medialibrary_flashmovie', 'allow_comments')

        # Deleting field 'Document.creation_date'
        db.delete_column('medialibrary_document', 'creation_date')

        # Deleting field 'Document.modification_date'
        db.delete_column('medialibrary_document', 'modification_date')

        # Deleting field 'Document.allow_comments'
        db.delete_column('medialibrary_document', 'allow_comments')

        # Deleting field 'ExternalContent.creation_date'
        db.delete_column('medialibrary_externalcontent', 'creation_date')

        # Deleting field 'ExternalContent.modification_date'
        db.delete_column('medialibrary_externalcontent', 'modification_date')

        # Deleting field 'ExternalContent.allow_comments'
        db.delete_column('medialibrary_externalcontent', 'allow_comments')

        # Deleting field 'SoundTrack.creation_date'
        db.delete_column('medialibrary_soundtrack', 'creation_date')

        # Deleting field 'SoundTrack.modification_date'
        db.delete_column('medialibrary_soundtrack', 'modification_date')

        # Deleting field 'SoundTrack.allow_comments'
        db.delete_column('medialibrary_soundtrack', 'allow_comments')

        # Deleting field 'Picture.creation_date'
        db.delete_column('medialibrary_picture', 'creation_date')

        # Deleting field 'Picture.modification_date'
        db.delete_column('medialibrary_picture', 'modification_date')

        # Deleting field 'Picture.allow_comments'
        db.delete_column('medialibrary_picture', 'allow_comments')


    models = {
        'collections.categorization': {
            'Meta': {'object_name': 'Categorization'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'categorizations'", 'to': "orm['collections.Category']"}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.category': {
            'Meta': {'unique_together': "(('collection', 'name'),)", 'object_name': 'Category'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'collection': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'collection categories'", 'to': "orm['collections.Collection']"}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "u'children'", 'null': 'True', 'to': "orm['collections.Category']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.collection': {
            'Meta': {'object_name': 'Collection'},
            'content_types': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['contenttypes.ContentType']", 'db_index': 'True', 'symmetrical': 'False'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50'}),
            'navigation_root': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'visible': ('django.db.models.fields.BooleanField', [], {'default': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'cyclope.relatedcontent': {
            'Meta': {'ordering': "['order']", 'object_name': 'RelatedContent'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'other_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'other_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'related_contents_rt'", 'to': "orm['contenttypes.ContentType']"}),
            'self_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'self_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'related_contents_lt'", 'to': "orm['contenttypes.ContentType']"})
        },
        'medialibrary.document': {
            'Meta': {'object_name': 'Document'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'author': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'document': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100', 'blank': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

        },
        'medialibrary.externalcontent': {
            'Meta': {'object_name': 'ExternalContent'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'author': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'blank': 'True'}),
            'content_url': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100', 'blank': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'new_window': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'skip_detail': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

        },
        'medialibrary.flashmovie': {
            'Meta': {'object_name': 'FlashMovie'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'author': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'flash': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100', 'blank': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

        },
        'medialibrary.movieclip': {
            'Meta': {'object_name': 'MovieClip'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'author': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),
            'still': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100', 'blank': 'True'}),

            'video': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100'})
        },
        'medialibrary.picture': {
            'Meta': {'object_name': 'Picture'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'author': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

        },
        'medialibrary.regularfile': {
            'Meta': {'object_name': 'RegularFile'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'author': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'file': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '100', 'blank': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

        },
        'medialibrary.soundtrack': {
            'Meta': {'object_name': 'SoundTrack'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'audio': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250'}),
            'author': ('django.db.models.fields.CharField', [], {'db_index': 'True', 'max_length': '100', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now_add': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now()', 'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

        }
    }

    complete_apps = ['medialibrary']



# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        
        # Adding model 'ContactAddress'
        db.create_table('contacts_contactaddress', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('country', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['locations.Country'], null=True, blank=True)),
            ('region', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['locations.Region'], null=True, blank=True)),
            ('city', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['locations.City'], null=True, blank=True)),
            ('street_address', self.gf('django.db.models.fields.CharField')(max_length=255, blank=True)),
            ('phone_number', self.gf('django.db.models.fields.CharField')(max_length=40, blank=True)),
            ('post_office_box', self.gf('django.db.models.fields.CharField')(max_length=255, blank=True)),
            ('type', self.gf('django.db.models.fields.CharField')(max_length=1)),
            ('contact', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['contacts.Contact'])),
        ))
        db.send_create_signal('contacts', ['ContactAddress'])

        # Adding model 'Contact'
        db.create_table('contacts_contact', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=250, db_index=True)),
            ('slug', self.gf('autoslug.fields.AutoSlugField')(unique=True, max_length=50, populate_from=None, unique_with=(), db_index=True)),

            ('published', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('creation_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime(2010, 12, 30, 19, 39, 9, 69256))),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime(2010, 12, 30, 19, 39, 9, 69311), auto_now=True, blank=True)),
            ('allow_comments', self.gf('django.db.models.fields.CharField')(default='SITE', max_length=4)),
            ('given_name', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('family_name', self.gf('django.db.models.fields.CharField')(max_length=255, blank=True)),
            ('gender', self.gf('django.db.models.fields.CharField')(max_length=1)),
            ('email', self.gf('django.db.models.fields.EmailField')(max_length=75, blank=True)),
            ('web', self.gf('django.db.models.fields.CharField')(max_length=255, blank=True)),
            ('mobile_phone_number', self.gf('django.db.models.fields.CharField')(max_length=40, blank=True)),
        ))
        db.send_create_signal('contacts', ['Contact'])


    def backwards(self, orm):
        
        # Deleting model 'ContactAddress'
        db.delete_table('contacts_contactaddress')

        # Deleting model 'Contact'
        db.delete_table('contacts_contact')


    models = {
        'collections.categorization': {
            'Meta': {'object_name': 'Categorization'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'categorizations'", 'to': "orm['collections.Category']"}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.category': {
            'Meta': {'unique_together': "(('collection', 'name'),)", 'object_name': 'Category'},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'db_index': 'True'}),
            'collection': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'collection categories'", 'to': "orm['collections.Collection']"}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "u'children'", 'null': 'True', 'to': "orm['collections.Category']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'collections.collection': {
            'Meta': {'object_name': 'Collection'},
            'content_types': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['contenttypes.ContentType']", 'db_index': 'True', 'symmetrical': 'False'}),
            'default_list_view': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '255', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('filebrowser.fields.FileBrowseField', [], {'max_length': '250', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50'}),
            'navigation_root': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique_with': '()', 'max_length': '50', 'populate_from': 'None', 'db_index': 'True'}),
            'visible': ('django.db.models.fields.BooleanField', [], {'default': 'True'})
        },
        'contacts.contact': {
            'Meta': {'object_name': 'Contact'},
            'allow_comments': ('django.db.models.fields.CharField', [], {'default': "'SITE'", 'max_length': '4'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2010, 12, 30, 19, 39, 9, 69256)'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'family_name': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'gender': ('django.db.models.fields.CharField', [], {'max_length': '1'}),
            'given_name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mobile_phone_number': ('django.db.models.fields.CharField', [], {'max_length': '40', 'blank': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2010, 12, 30, 19, 39, 9, 69311)', 'auto_now': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'db_index': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'slug': ('autoslug.fields.AutoSlugField', [], {'unique': 'True', 'max_length': '50', 'populate_from': 'None', 'unique_with': '()', 'db_index': 'True'}),

            'web': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'})
        },
        'contacts.contactaddress': {
            'Meta': {'object_name': 'ContactAddress'},
            'city': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['locations.City']", 'null': 'True', 'blank': 'True'}),
            'contact': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contacts.Contact']"}),
            'country': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['locations.Country']", 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'phone_number': ('django.db.models.fields.CharField', [], {'max_length': '40', 'blank': 'True'}),
            'post_office_box': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'region': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['locations.Region']", 'null': 'True', 'blank': 'True'}),
            'street_address': ('django.db.models.fields.CharField', [], {'max_length': '255', 'blank': 'True'}),
            'type': ('django.db.models.fields.CharField', [], {'max_length': '1'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'cyclope.relatedcontent': {
            'Meta': {'ordering': "['order']", 'object_name': 'RelatedContent'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'order': ('django.db.models.fields.IntegerField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'other_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'other_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'related_contents_rt'", 'to': "orm['contenttypes.ContentType']"}),
            'self_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'self_type': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'related_contents_lt'", 'to': "orm['contenttypes.ContentType']"})
        },
        'locations.city': {
            'Meta': {'object_name': 'City'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'region': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['locations.Region']"})
        },
        'locations.country': {
            'Meta': {'object_name': 'Country'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'locations.region': {
            'Meta': {'object_name': 'Region'},
            'country': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['locations.Country']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        }
    }

    complete_apps = ['contacts']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
core.collections.models
-----------------------
Django models for generic categorization of content objects
"""
import random
from operator import attrgetter
from collections import defaultdict

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes import generic
from django.db.models.signals import m2m_changed

import mptt
from jsonfield import JSONField
from autoslug.fields import AutoSlugField
from filebrowser.fields import FileBrowseField

import cyclope
from cyclope.utils import ThumbnailMixin


class Collection(models.Model, ThumbnailMixin):
    """A facility for creating custom content collections.
    """

    name = models.CharField(_('name'), max_length=100, unique=True)
    slug = AutoSlugField(populate_from='name', always_update=False,
                         editable=True, blank=True)
    # collections that aren't visible can be used to customize content behaviour
    visible = models.BooleanField(_('visible'), default=True)
    # the idea with navigation_root collections is that
    # URLS for these collections should be simplified. not used at the moment.
    navigation_root = models.BooleanField(_('navigation root'), default=False)
    content_types = models.ManyToManyField(ContentType, db_index=True,
                                           verbose_name=_('content types'))
    description = models.TextField(_('description'), blank=True, null=True)
    image =  FileBrowseField(_('image'), max_length=250, format='Image',
                             blank=True)
    default_list_view = models.CharField(_('default list view'), max_length=255,
                                         blank=True, default='')
    view_options = JSONField(default='{}') # default is taken from ViewOptionsForm

    def get_absolute_url(self):
        return '/%s/%s/' % (self._meta.object_name.lower(), self.slug)

    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name = _('collection')
        verbose_name_plural = _('collections')

def changed_ctypes(sender, instance, action, reverse, model, pk_set, **kwargs):
    ## we remove previous categorizations that were set for content types
    ## that are no longer accepted by the collection
    if action == 'post_add' and pk_set:
        Categorization = models.get_model('collections', 'categorization')
        cats = Categorization.objects.filter(
            category__collection=instance).exclude(content_type__pk__in=pk_set).delete()

m2m_changed.connect(changed_ctypes, sender=Collection.content_types.through)


class Category(models.Model, ThumbnailMixin):
    """Categories are associated with a specific Collection,
    and can be generically usable with any content type.
    """

    collection = models.ForeignKey(Collection,
        verbose_name=_('collection'), related_name='categories')
    name = models.CharField(_('name'), max_length=100)
    slug = AutoSlugField(populate_from='name', unique=True, db_index=True,
                         always_update=False, editable=True, blank=True)
    parent = models.ForeignKey('self', verbose_name=_('parent'),
                              related_name='children', null=True, blank=True)
    active = models.BooleanField(_('active'), default=True, db_index=True)
    description = models.TextField(_('description'), blank=True, null=True)
    image =  FileBrowseField(_('image'), max_length=250, format='Image',
                             blank=True)

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        return '/%s/%s/' % (self._meta.object_name.lower(), self.slug)

    def valid_parents(self):
        return Category.tree.filter(pk__isnot=self.pk)

    def save(self, moving_childs=False, *args, **kwargs):
        # If is not a new Category and the Collection is changed, we move all
        # childrens to the new Collection adding the necesary content_types to
        # the new collection.
        if self.pk is not None:
            old_category = Category.objects.get(pk=self.pk)
            if old_category.collection != self.collection:
                # If we are moving a non root category it must be root in
                # the new collection
                if self.is_child_node() and not moving_childs:
                    self.parent = None
                # Add the content_types of the categorizations to new collection
                descendants = old_category.get_descendants()
                all_categories = [self] + list(descendants)
                categorizations_list = Categorization.objects.filter(category__in=all_categories)
                content_types = list(set([cat.content_type for cat in categorizations_list]))
                self.collection.content_types.add(*content_types)

                for child in descendants:
                    child.collection = self.collection
                    child.save(moving_childs=True)
        super(Category, self).save(*args, **kwargs)

    class Meta:
        unique_together = ('collection', 'name')
        verbose_name = _('category')
        verbose_name_plural = _('categories')
        get_latest_by = "pk"

mptt.register(Category)


class CategorizationManager(models.Manager):

    def get_for_object(self, obj):
        """Get all Categorizations for an instance of a content object.

        Args:
          obj: a model or instance
        """

        ctype = ContentType.objects.get_for_model(obj)
        return self.filter(content_type__pk=ctype.pk, object_id=obj.pk)

    def get_for_ctype(self, ctype):
        """Get all Categorizations available for this content_type.

        Args:
          ctype: a ContentType instance
        """
        return self.filter(content_type__pk=ctype.pk)

    def get_for_category(self, category, sort_property="name", limit=None,
                         traverse_children=False, reverse=False):
        # Here are two ways of order categorizations by a content_object attribute:
        #
        # 1) using prefetch_related:
        #      it's short but it prefetches ALL fields from all the instances.
        #      also it makes 1 query for content_type (only content_types that are used in this category)
        #      This implementation is commented below in case django add defer/only support to prefetch_related.
        #
        #      categorizations = Categorization.objects.filter(category__in=categories).prefetch_related("content_object")
        #
        # 2) doing what prefetch_related does but only using needed fields.
        #
        categories = [category]
        if traverse_children:
            categories += list(category.get_descendants())

        # First fetch object_id's and content_types and build a dict with key on content_type
        cats = Categorization.objects.filter(category__in=categories)
        ct_vals = defaultdict(list)
        for cat_id, obj_id, ct_id in cats.values_list("pk", "object_id", "content_type_id"):
            ct_vals[ct_id].append(obj_id)

        if sort_property == "random":
            cats = list(cats)
            random.shuffle(cats)
        else:
            # Iterate over content_types fetching the sort_key of the content_object and saving in sort_attrs dict
            sort_attrs = {}
            def chunks(l, n):
                """ Yield successive n-sized chunks from l.
                """
                for i in xrange(0, len(l), n):
                    yield l[i:i+n]
            for ct_id, object_ids in ct_vals.iteritems():
                ct = ContentType.objects.get_for_id(ct_id)
                for object_ids in chunks(object_ids, 450):
                    for obj_id, val in ct.get_all_objects_for_this_type(pk__in=object_ids).values_list("pk", sort_property):
                        sort_attrs[(ct_id, obj_id)] = val
            cats = sorted(cats, key=lambda c: sort_attrs[(c.content_type_id, c.object_id)],
                          reverse=reverse)
        return cats[slice(limit)]



class Categorization(models.Model):
    """Represents the association of a catergory and a content object."""

    category = models.ForeignKey('Category', verbose_name=_('category'),
                                 db_index=True, related_name='categorizations')
    content_type = models.ForeignKey(ContentType, db_index=True,
                                     verbose_name=_('content type'))
    object_id = models.PositiveIntegerField(db_index=True)
    content_object = generic.GenericForeignKey('content_type', 'object_id')

    objects = CategorizationManager()

    @property
    def object_modification_date(self):
        return self.content_object.modification_date

    @property
    def object_creation_date(self):
        return self.content_object.creation_date

    def __unicode__(self):
        return '%(collection_name)s: %(category_name)s' % {
            'collection_name': self.category.collection.name,
            'category_name': self.category.name}

    class Meta:
        verbose_name = _('categorization')
        verbose_name_plural = _('categorizations')
#        ordering = ('object_modification_date',)


class Collectible(models.Model):
    """Base class for collectible objects
    """
    categories = generic.GenericRelation('Categorization',
        content_type_field='content_type', object_id_field='object_id',
        verbose_name = _('categories'))

    # activate custom admin filter
    categories.category_filter = True

    def is_orphan(self):
        return not self.categories.exists()
    is_orphan.short_description = _('is orphan')

    class Meta:
        abstract = True



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2010 Código Sur - Nuestra América Asoc. Civil / Fundación Pacificar.
# All rights reserved.
#
# This file is part of Cyclope.
#
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Cyclope is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
core.frontend
-------------
"""


from django.http import HttpResponse
from django.utils.translation import ugettext_lazy as _
from django.template import RequestContext
from django.shortcuts import get_object_or_404

from sites import site

from cyclope.utils import template_for_request


class FrontendView(object):
    """Parent class for frontend views.

    Class Attributes:

        name: name of the view (must be unique among registered views)

        verbose_name

        params(dict): keyword arguments that will be passed to get_response

        options_form(form): a forms.Form subclass defining options for the view

        is_default(boolean): is this the default view for the model?

        is_instance_view(boolean): sets whether the view needs a content_object

        is_content_view(boolean): sets whether the view can be used for main page content

        is_region_view(boolean): sets whether the view can be included in layout regions
    """

    name = ''
    __name__ = property(lambda self: self.name) # Needed for compatibility
    verbose_name = ''
    is_default = False
    is_instance_view = True
    is_content_view = False
    is_region_view = False
    extra_context = {}
    params = {}
    options_form = None

    def __call__(self, request, region_name=None, slug=None, content_object=None, view_options=None):
        """
        Arguments:
            Either content_object or slug must be set

        Returns:
            a string if the view is called from within a region templatetag
            an HttpResponse otherwise
        """
        options = self.get_default_options()
        if view_options:
            options.update(view_options)

        if region_name:
            host_template = 'cyclope/inline_view.html'
        else:
            host_template = template_for_request(request)

        req_context = RequestContext(request, {'host_template': host_template,
                                              'region_name': region_name,
                                              'view_options': options})

        if self.is_instance_view:
            if not content_object:
                content_object = get_object_or_404(self.model, slug=slug)

            req_context["current_object"] = content_object
            if self.is_content_view and not region_name:
                if hasattr(content_object, "name"):
                    title = _(content_object.name)
                else:
                    title = unicode(content_object)
                req_context["title"] = title.capitalize()

            response = self.get_response(request, req_context, options, content_object)
        else:
            response = self.get_response(request, req_context, options)

        # region_name will hold a value if the view was called from a region templatetag
        if not region_name:
            if not isinstance(response, HttpResponse):
                response = HttpResponse(response)

        return response

    def get_response(self, request, req_context, options, content_object=None):
        """Must be overriden by inheriting class and return a the view content
        """
        raise NotImplementedError()

    def get_url_pattern(self, model):
        if self.is_default:
            return '%s/(?P<slug>[\w-]+)/$'\
                    % (model._meta.object_name.lower())

        if self.is_instance_view:
            return '%s/(?P<slug>[\w-]+)/View/%s'\
                    % (model._meta.object_name.lower(), self.name)
        else:
            return '%s/View/%s'\
                    % (model._meta.object_name.lower(), self.name)

    def get_default_options(self):
        options = {}
        if self.options_form:
            form = self.options_form()
            for field_name, field in form.fields.iteritems():
                options[field_name] = field.initial
        return options

##########
# autodiscover() is an almost exact copy of
# django.contrib.admin.autodiscover()

# A flag to tell us if autodiscover is running.  autodiscover will set this to
# True while running, and False when it finishes.
LOADING = False

def autodiscover():
    """Auto-discover frontend_views module for each INSTALLED_APP
    and fail silently when not present.

    This forces an import on them to register frontend views.
    """
    global LOADING
    if LOADING:
        return
    LOADING = True

    import imp
    from django.utils.importlib import import_module
    from django.conf import settings

    for app in settings.INSTALLED_APPS:
        mod = import_module(app)
        try:
            app_path = mod.__path__
        except AttributeError:
            continue
        try:
            imp.find_module('frontend_views', app_path)
        except ImportError:
            continue
        import_module('%s.frontend_views' % app)

    for model in site._registry:
        default_view = [ view
                        for view in site._registry[model]
                        if view.is_default == True ]
        if len(default_view) == 0:
            raise(Exception(
                _(u'No default view has been set for %s' % model)))
        elif len(default_view) > 1:
            raise(Exception(
                _(u'You can set only one default view for %s' % model)))

    LOADING = False

################
